@@ -62,12 +62,12 @@ enum eCommandKind {
 void err_msg(char* msg, char* sname, int line);
     // 顼å
 
-string_obj* gAncestalMemoryPipeIn;
+extern string_obj* gAncestalMemoryPipeIn;
     // ȥåץ٥ޥѤΥѥ
-string_obj* gAncestalMemoryPipeOut;
+extern string_obj* gAncestalMemoryPipeOut;
     // ȥåץ٥ޥѤΥѥ
 
-char gTmpDir[PATH_MAX];
+extern char gTmpDir[PATH_MAX];
     // ե֤
 
 extern char* gStatmentKindStrs[kCommand+1];
